/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://code.google.com/p/google-apis-client-generator/
 * (build: 2013-08-14 15:32:06 UTC)
 * on 2013-08-19 at 21:14:35 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.dfareporting;

/**
 * Service definition for Dfareporting (v1.2).
 *
 * <p>
 * Lets you create, run and download reports.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/doubleclick-advertisers/reporting/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link DfareportingRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Dfareporting extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION >= 15,
        "You are currently running with version %s of google-api-client. " +
        "You need at least version 1.15 of google-api-client to run version " +
        "1.16.0-rc of the DFA Reporting API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "dfareporting/v1.2/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Dfareporting(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  Dfareporting(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the DimensionValues collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.DimensionValues.List request = dfareporting.dimensionValues().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public DimensionValues dimensionValues() {
    return new DimensionValues();
  }

  /**
   * The "dimensionValues" collection of methods.
   */
  public class DimensionValues {

    /**
     * Retrieves list of report dimension values for a list of filters.
     *
     * Create a request for the method "dimensionValues.query".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param content the {@link com.google.api.services.dfareporting.model.DimensionValueRequest}
     * @return the request
     */
    public Query query(java.lang.Long profileId, com.google.api.services.dfareporting.model.DimensionValueRequest content) throws java.io.IOException {
      Query result = new Query(profileId, content);
      initialize(result);
      return result;
    }

    public class Query extends DfareportingRequest<com.google.api.services.dfareporting.model.DimensionValueList> {

      private static final String REST_PATH = "userprofiles/{profileId}/dimensionvalues/query";

      /**
       * Retrieves list of report dimension values for a list of filters.
       *
       * Create a request for the method "dimensionValues.query".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
       * <p> {@link
       * Query#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param content the {@link com.google.api.services.dfareporting.model.DimensionValueRequest}
       * @since 1.13
       */
      protected Query(java.lang.Long profileId, com.google.api.services.dfareporting.model.DimensionValueRequest content) {
        super(Dfareporting.this, "POST", REST_PATH, content, com.google.api.services.dfareporting.model.DimensionValueList.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public Query setAlt(java.lang.String alt) {
        return (Query) super.setAlt(alt);
      }

      @Override
      public Query setFields(java.lang.String fields) {
        return (Query) super.setFields(fields);
      }

      @Override
      public Query setKey(java.lang.String key) {
        return (Query) super.setKey(key);
      }

      @Override
      public Query setOauthToken(java.lang.String oauthToken) {
        return (Query) super.setOauthToken(oauthToken);
      }

      @Override
      public Query setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Query) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Query setQuotaUser(java.lang.String quotaUser) {
        return (Query) super.setQuotaUser(quotaUser);
      }

      @Override
      public Query setUserIp(java.lang.String userIp) {
        return (Query) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Query setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The value of the nextToken from the previous result page. */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** The value of the nextToken from the previous result page.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous result page. */
      public Query setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 100]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public Query setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public Query set(String parameterName, Object value) {
        return (Query) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Files collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.Files.List request = dfareporting.files().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Files files() {
    return new Files();
  }

  /**
   * The "files" collection of methods.
   */
  public class Files {

    /**
     * Retrieves a report file by its report ID and file ID.
     *
     * Create a request for the method "files.get".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param reportId The ID of the report.
     * @param fileId The ID of the report file.
     * @return the request
     */
    public Get get(java.lang.Long reportId, java.lang.Long fileId) throws java.io.IOException {
      Get result = new Get(reportId, fileId);
      initialize(result);
      return result;
    }

    public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.File> {

      private static final String REST_PATH = "reports/{reportId}/files/{fileId}";

      /**
       * Retrieves a report file by its report ID and file ID.
       *
       * Create a request for the method "files.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param reportId The ID of the report.
       * @param fileId The ID of the report file.
       * @since 1.13
       */
      protected Get(java.lang.Long reportId, java.lang.Long fileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.File.class);
        this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
        this.fileId = com.google.api.client.util.Preconditions.checkNotNull(fileId, "Required parameter fileId must be specified.");
        initializeMediaDownload();
      }

      @Override
      public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
        super.executeMediaAndDownloadTo(outputStream);
      }

      @Override
      public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
        return super.executeMediaAsInputStream();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
        return super.executeMedia();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private java.lang.Long reportId;

      /** The ID of the report.
       */
      public java.lang.Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Get setReportId(java.lang.Long reportId) {
        this.reportId = reportId;
        return this;
      }

      /** The ID of the report file. */
      @com.google.api.client.util.Key
      private java.lang.Long fileId;

      /** The ID of the report file.
       */
      public java.lang.Long getFileId() {
        return fileId;
      }

      /** The ID of the report file. */
      public Get setFileId(java.lang.Long fileId) {
        this.fileId = fileId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Lists files for a user profile.
     *
     * Create a request for the method "files.list".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA profile ID.
     * @return the request
     */
    public List list(java.lang.Long profileId) throws java.io.IOException {
      List result = new List(profileId);
      initialize(result);
      return result;
    }

    public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.FileList> {

      private static final String REST_PATH = "userprofiles/{profileId}/files";

      /**
       * Lists files for a user profile.
       *
       * Create a request for the method "files.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA profile ID.
       * @since 1.13
       */
      protected List(java.lang.Long profileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.FileList.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The DFA profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA profile ID. */
      public List setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The field by which to sort the list. */
      @com.google.api.client.util.Key
      private java.lang.String sortField;

      /** The field by which to sort the list. [default: LAST_MODIFIED_TIME]
       */
      public java.lang.String getSortField() {
        return sortField;
      }

      /** The field by which to sort the list. */
      public List setSortField(java.lang.String sortField) {
        this.sortField = sortField;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 10]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** The value of the nextToken from the previous result page. */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** The value of the nextToken from the previous result page.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous result page. */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      @com.google.api.client.util.Key
      private java.lang.String sortOrder;

      /** Order of sorted results, default is 'DESCENDING'. [default: DESCENDING]
       */
      public java.lang.String getSortOrder() {
        return sortOrder;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      public List setSortOrder(java.lang.String sortOrder) {
        this.sortOrder = sortOrder;
        return this;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      @com.google.api.client.util.Key
      private java.lang.String scope;

      /** The scope that defines which results are returned, default is 'MINE'. [default: MINE]
       */
      public java.lang.String getScope() {
        return scope;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      public List setScope(java.lang.String scope) {
        this.scope = scope;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Reports collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.Reports.List request = dfareporting.reports().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Reports reports() {
    return new Reports();
  }

  /**
   * The "reports" collection of methods.
   */
  public class Reports {

    /**
     * Deletes a report by its ID.
     *
     * Create a request for the method "reports.delete".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @return the request
     */
    public Delete delete(java.lang.Long profileId, java.lang.Long reportId) throws java.io.IOException {
      Delete result = new Delete(profileId, reportId);
      initialize(result);
      return result;
    }

    public class Delete extends DfareportingRequest<Void> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Deletes a report by its ID.
       *
       * Create a request for the method "reports.delete".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link
       * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @since 1.13
       */
      protected Delete(java.lang.Long profileId, java.lang.Long reportId) {
        super(Dfareporting.this, "DELETE", REST_PATH, null, Void.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Delete setAlt(java.lang.String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(java.lang.String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(java.lang.String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(java.lang.String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(java.lang.String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(java.lang.String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Delete setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private java.lang.Long reportId;

      /** The ID of the report.
       */
      public java.lang.Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Delete setReportId(java.lang.Long reportId) {
        this.reportId = reportId;
        return this;
      }

      @Override
      public Delete set(String parameterName, Object value) {
        return (Delete) super.set(parameterName, value);
      }
    }
    /**
     * Retrieves a report by its ID.
     *
     * Create a request for the method "reports.get".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @return the request
     */
    public Get get(java.lang.Long profileId, java.lang.Long reportId) throws java.io.IOException {
      Get result = new Get(profileId, reportId);
      initialize(result);
      return result;
    }

    public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Retrieves a report by its ID.
       *
       * Create a request for the method "reports.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @since 1.13
       */
      protected Get(java.lang.Long profileId, java.lang.Long reportId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Get setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private java.lang.Long reportId;

      /** The ID of the report.
       */
      public java.lang.Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Get setReportId(java.lang.Long reportId) {
        this.reportId = reportId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Creates a report.
     *
     * Create a request for the method "reports.insert".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param content the {@link com.google.api.services.dfareporting.model.Report}
     * @return the request
     */
    public Insert insert(java.lang.Long profileId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
      Insert result = new Insert(profileId, content);
      initialize(result);
      return result;
    }

    public class Insert extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports";

      /**
       * Creates a report.
       *
       * Create a request for the method "reports.insert".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link
       * Insert#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @since 1.13
       */
      protected Insert(java.lang.Long profileId, com.google.api.services.dfareporting.model.Report content) {
        super(Dfareporting.this, "POST", REST_PATH, content, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getName(), "Report.getName()");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getType(), "Report.getType()");
      }

      @Override
      public Insert setAlt(java.lang.String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(java.lang.String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(java.lang.String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(java.lang.String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(java.lang.String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(java.lang.String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Insert setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      @Override
      public Insert set(String parameterName, Object value) {
        return (Insert) super.set(parameterName, value);
      }
    }
    /**
     * Retrieves list of reports.
     *
     * Create a request for the method "reports.list".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @return the request
     */
    public List list(java.lang.Long profileId) throws java.io.IOException {
      List result = new List(profileId);
      initialize(result);
      return result;
    }

    public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.ReportList> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports";

      /**
       * Retrieves list of reports.
       *
       * Create a request for the method "reports.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @since 1.13
       */
      protected List(java.lang.Long profileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.ReportList.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public List setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The field by which to sort the list. */
      @com.google.api.client.util.Key
      private java.lang.String sortField;

      /** The field by which to sort the list. [default: LAST_MODIFIED_TIME]
       */
      public java.lang.String getSortField() {
        return sortField;
      }

      /** The field by which to sort the list. */
      public List setSortField(java.lang.String sortField) {
        this.sortField = sortField;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 10]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public List setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** The value of the nextToken from the previous result page. */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** The value of the nextToken from the previous result page.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous result page. */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      @com.google.api.client.util.Key
      private java.lang.String sortOrder;

      /** Order of sorted results, default is 'DESCENDING'. [default: DESCENDING]
       */
      public java.lang.String getSortOrder() {
        return sortOrder;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      public List setSortOrder(java.lang.String sortOrder) {
        this.sortOrder = sortOrder;
        return this;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      @com.google.api.client.util.Key
      private java.lang.String scope;

      /** The scope that defines which results are returned, default is 'MINE'. [default: MINE]
       */
      public java.lang.String getScope() {
        return scope;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      public List setScope(java.lang.String scope) {
        this.scope = scope;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }
    /**
     * Updates a report. This method supports patch semantics.
     *
     * Create a request for the method "reports.patch".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @param content the {@link com.google.api.services.dfareporting.model.Report}
     * @return the request
     */
    public Patch patch(java.lang.Long profileId, java.lang.Long reportId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
      Patch result = new Patch(profileId, reportId, content);
      initialize(result);
      return result;
    }

    public class Patch extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Updates a report. This method supports patch semantics.
       *
       * Create a request for the method "reports.patch".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link
       * Patch#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @since 1.13
       */
      protected Patch(java.lang.Long profileId, java.lang.Long reportId, com.google.api.services.dfareporting.model.Report content) {
        super(Dfareporting.this, "PATCH", REST_PATH, content, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Patch setAlt(java.lang.String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(java.lang.String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(java.lang.String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(java.lang.String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(java.lang.String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(java.lang.String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Patch setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private java.lang.Long reportId;

      /** The ID of the report.
       */
      public java.lang.Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Patch setReportId(java.lang.Long reportId) {
        this.reportId = reportId;
        return this;
      }

      @Override
      public Patch set(String parameterName, Object value) {
        return (Patch) super.set(parameterName, value);
      }
    }
    /**
     * Runs a report.
     *
     * Create a request for the method "reports.run".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Run#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA profile ID.
     * @param reportId The ID of the report.
     * @return the request
     */
    public Run run(java.lang.Long profileId, java.lang.Long reportId) throws java.io.IOException {
      Run result = new Run(profileId, reportId);
      initialize(result);
      return result;
    }

    public class Run extends DfareportingRequest<com.google.api.services.dfareporting.model.File> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}/run";

      /**
       * Runs a report.
       *
       * Create a request for the method "reports.run".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Run#execute()} method to invoke the remote operation. <p>
       * {@link Run#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA profile ID.
       * @param reportId The ID of the report.
       * @since 1.13
       */
      protected Run(java.lang.Long profileId, java.lang.Long reportId) {
        super(Dfareporting.this, "POST", REST_PATH, null, com.google.api.services.dfareporting.model.File.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Run setAlt(java.lang.String alt) {
        return (Run) super.setAlt(alt);
      }

      @Override
      public Run setFields(java.lang.String fields) {
        return (Run) super.setFields(fields);
      }

      @Override
      public Run setKey(java.lang.String key) {
        return (Run) super.setKey(key);
      }

      @Override
      public Run setOauthToken(java.lang.String oauthToken) {
        return (Run) super.setOauthToken(oauthToken);
      }

      @Override
      public Run setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Run) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Run setQuotaUser(java.lang.String quotaUser) {
        return (Run) super.setQuotaUser(quotaUser);
      }

      @Override
      public Run setUserIp(java.lang.String userIp) {
        return (Run) super.setUserIp(userIp);
      }

      /** The DFA profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA profile ID. */
      public Run setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private java.lang.Long reportId;

      /** The ID of the report.
       */
      public java.lang.Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Run setReportId(java.lang.Long reportId) {
        this.reportId = reportId;
        return this;
      }

      /** If set and true, tries to run the report synchronously. */
      @com.google.api.client.util.Key
      private java.lang.Boolean synchronous;

      /** If set and true, tries to run the report synchronously.
       */
      public java.lang.Boolean getSynchronous() {
        return synchronous;
      }

      /** If set and true, tries to run the report synchronously. */
      public Run setSynchronous(java.lang.Boolean synchronous) {
        this.synchronous = synchronous;
        return this;
      }

      @Override
      public Run set(String parameterName, Object value) {
        return (Run) super.set(parameterName, value);
      }
    }
    /**
     * Updates a report.
     *
     * Create a request for the method "reports.update".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @param content the {@link com.google.api.services.dfareporting.model.Report}
     * @return the request
     */
    public Update update(java.lang.Long profileId, java.lang.Long reportId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
      Update result = new Update(profileId, reportId, content);
      initialize(result);
      return result;
    }

    public class Update extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Updates a report.
       *
       * Create a request for the method "reports.update".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link
       * Update#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @since 1.13
       */
      protected Update(java.lang.Long profileId, java.lang.Long reportId, com.google.api.services.dfareporting.model.Report content) {
        super(Dfareporting.this, "PUT", REST_PATH, content, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getAccountId(), "Report.getAccountId()");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getId(), "Report.getId()");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getLastModifiedTime(), "Report.getLastModifiedTime()");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getName(), "Report.getName()");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getOwnerProfileId(), "Report.getOwnerProfileId()");
        checkRequiredParameter(content, "content");
        checkRequiredParameter(content.getType(), "Report.getType()");
      }

      @Override
      public Update setAlt(java.lang.String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(java.lang.String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(java.lang.String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(java.lang.String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(java.lang.String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(java.lang.String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The DFA user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Update setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private java.lang.Long reportId;

      /** The ID of the report.
       */
      public java.lang.Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Update setReportId(java.lang.Long reportId) {
        this.reportId = reportId;
        return this;
      }

      @Override
      public Update set(String parameterName, Object value) {
        return (Update) super.set(parameterName, value);
      }
    }

    /**
     * An accessor for creating requests from the Files collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Dfareporting dfareporting = new Dfareporting(...);}
     *   {@code Dfareporting.Files.List request = dfareporting.files().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Files files() {
      return new Files();
    }

    /**
     * The "files" collection of methods.
     */
    public class Files {

      /**
       * Retrieves a report file.
       *
       * Create a request for the method "files.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param profileId The DFA profile ID.
       * @param reportId The ID of the report.
       * @param fileId The ID of the report file.
       * @return the request
       */
      public Get get(java.lang.Long profileId, java.lang.Long reportId, java.lang.Long fileId) throws java.io.IOException {
        Get result = new Get(profileId, reportId, fileId);
        initialize(result);
        return result;
      }

      public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.File> {

        private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}/files/{fileId}";

        /**
         * Retrieves a report file.
         *
         * Create a request for the method "files.get".
         *
         * This request holds the parameters needed by the the dfareporting server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param profileId The DFA profile ID.
         * @param reportId The ID of the report.
         * @param fileId The ID of the report file.
         * @since 1.13
         */
        protected Get(java.lang.Long profileId, java.lang.Long reportId, java.lang.Long fileId) {
          super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.File.class);
          this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
          this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
          this.fileId = com.google.api.client.util.Preconditions.checkNotNull(fileId, "Required parameter fileId must be specified.");
          initializeMediaDownload();
        }

        @Override
        public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
          super.executeMediaAndDownloadTo(outputStream);
        }

        @Override
        public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
          return super.executeMediaAsInputStream();
        }

        @Override
        public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
          return super.executeMedia();
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(java.lang.String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(java.lang.String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(java.lang.String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(java.lang.String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(java.lang.String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(java.lang.String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** The DFA profile ID. */
        @com.google.api.client.util.Key
        private java.lang.Long profileId;

        /** The DFA profile ID.
         */
        public java.lang.Long getProfileId() {
          return profileId;
        }

        /** The DFA profile ID. */
        public Get setProfileId(java.lang.Long profileId) {
          this.profileId = profileId;
          return this;
        }

        /** The ID of the report. */
        @com.google.api.client.util.Key
        private java.lang.Long reportId;

        /** The ID of the report.
         */
        public java.lang.Long getReportId() {
          return reportId;
        }

        /** The ID of the report. */
        public Get setReportId(java.lang.Long reportId) {
          this.reportId = reportId;
          return this;
        }

        /** The ID of the report file. */
        @com.google.api.client.util.Key
        private java.lang.Long fileId;

        /** The ID of the report file.
         */
        public java.lang.Long getFileId() {
          return fileId;
        }

        /** The ID of the report file. */
        public Get setFileId(java.lang.Long fileId) {
          this.fileId = fileId;
          return this;
        }

        @Override
        public Get set(String parameterName, Object value) {
          return (Get) super.set(parameterName, value);
        }
      }
      /**
       * Lists files for a report.
       *
       * Create a request for the method "files.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param profileId The DFA profile ID.
       * @param reportId The ID of the parent report.
       * @return the request
       */
      public List list(java.lang.Long profileId, java.lang.Long reportId) throws java.io.IOException {
        List result = new List(profileId, reportId);
        initialize(result);
        return result;
      }

      public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.FileList> {

        private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}/files";

        /**
         * Lists files for a report.
         *
         * Create a request for the method "files.list".
         *
         * This request holds the parameters needed by the the dfareporting server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
         * must be called to initialize this instance immediately after invoking the constructor. </p>
         *
         * @param profileId The DFA profile ID.
         * @param reportId The ID of the parent report.
         * @since 1.13
         */
        protected List(java.lang.Long profileId, java.lang.Long reportId) {
          super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.FileList.class);
          this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
          this.reportId = com.google.api.client.util.Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(java.lang.String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(java.lang.String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(java.lang.String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(java.lang.String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(java.lang.Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(java.lang.String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(java.lang.String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** The DFA profile ID. */
        @com.google.api.client.util.Key
        private java.lang.Long profileId;

        /** The DFA profile ID.
         */
        public java.lang.Long getProfileId() {
          return profileId;
        }

        /** The DFA profile ID. */
        public List setProfileId(java.lang.Long profileId) {
          this.profileId = profileId;
          return this;
        }

        /** The ID of the parent report. */
        @com.google.api.client.util.Key
        private java.lang.Long reportId;

        /** The ID of the parent report.
         */
        public java.lang.Long getReportId() {
          return reportId;
        }

        /** The ID of the parent report. */
        public List setReportId(java.lang.Long reportId) {
          this.reportId = reportId;
          return this;
        }

        /** The field by which to sort the list. */
        @com.google.api.client.util.Key
        private java.lang.String sortField;

        /** The field by which to sort the list. [default: LAST_MODIFIED_TIME]
         */
        public java.lang.String getSortField() {
          return sortField;
        }

        /** The field by which to sort the list. */
        public List setSortField(java.lang.String sortField) {
          this.sortField = sortField;
          return this;
        }

        /** Maximum number of results to return. */
        @com.google.api.client.util.Key
        private java.lang.Integer maxResults;

        /** Maximum number of results to return.

       [minimum: 0] [maximum: 10]
         */
        public java.lang.Integer getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return. */
        public List setMaxResults(java.lang.Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** The value of the nextToken from the previous result page. */
        @com.google.api.client.util.Key
        private java.lang.String pageToken;

        /** The value of the nextToken from the previous result page.
         */
        public java.lang.String getPageToken() {
          return pageToken;
        }

        /** The value of the nextToken from the previous result page. */
        public List setPageToken(java.lang.String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** Order of sorted results, default is 'DESCENDING'. */
        @com.google.api.client.util.Key
        private java.lang.String sortOrder;

        /** Order of sorted results, default is 'DESCENDING'. [default: DESCENDING]
         */
        public java.lang.String getSortOrder() {
          return sortOrder;
        }

        /** Order of sorted results, default is 'DESCENDING'. */
        public List setSortOrder(java.lang.String sortOrder) {
          this.sortOrder = sortOrder;
          return this;
        }

        @Override
        public List set(String parameterName, Object value) {
          return (List) super.set(parameterName, value);
        }
      }

    }
  }

  /**
   * An accessor for creating requests from the UserProfiles collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.UserProfiles.List request = dfareporting.userProfiles().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public UserProfiles userProfiles() {
    return new UserProfiles();
  }

  /**
   * The "userProfiles" collection of methods.
   */
  public class UserProfiles {

    /**
     * Gets one user profile by ID.
     *
     * Create a request for the method "userProfiles.get".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param profileId The user profile ID.
     * @return the request
     */
    public Get get(java.lang.Long profileId) throws java.io.IOException {
      Get result = new Get(profileId);
      initialize(result);
      return result;
    }

    public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.UserProfile> {

      private static final String REST_PATH = "userprofiles/{profileId}";

      /**
       * Gets one user profile by ID.
       *
       * Create a request for the method "userProfiles.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param profileId The user profile ID.
       * @since 1.13
       */
      protected Get(java.lang.Long profileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.UserProfile.class);
        this.profileId = com.google.api.client.util.Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The user profile ID. */
      @com.google.api.client.util.Key
      private java.lang.Long profileId;

      /** The user profile ID.
       */
      public java.lang.Long getProfileId() {
        return profileId;
      }

      /** The user profile ID. */
      public Get setProfileId(java.lang.Long profileId) {
        this.profileId = profileId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Retrieves list of user profiles for a user.
     *
     * Create a request for the method "userProfiles.list".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.UserProfileList> {

      private static final String REST_PATH = "userprofiles";

      /**
       * Retrieves list of user profiles for a user.
       *
       * Create a request for the method "userProfiles.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.UserProfileList.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }

  }

  /**
   * Builder for {@link Dfareporting}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Dfareporting}. */
    @Override
    public Dfareporting build() {
      return new Dfareporting(this);
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link DfareportingRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setDfareportingRequestInitializer(
        DfareportingRequestInitializer dfareportingRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(dfareportingRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
